
library(tcltk)

library(MuMIn)

library(DescTools)

library(questionr)

library(DHARMa)



#Load the standardised section table of airflow statistics for the wind direction to be modelled, on Skomer:

SectorsTable<-read.csv(file.choose())




#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR SW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR SW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR SW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR SW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>Any COUNT HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>


SectorsTable$ColPresence[SectorsTable$Count==0]<-0
SectorsTable$ColPresence[SectorsTable$Count>0]<-1

SectorsTable$ColPresence<-as.numeric(SectorsTable$ColPresence)



#Global model
modelGMLSWAnyCOunt<-glm(ColPresence ~
                          
                          PMedian+U_2Skewness+TKEIQR
                        +PIQR+MeanSectorSlope+PSkewness
                        +TKEMedian+TISkewness+HorizontalMedian
                        +U_2IQR
                       
                        
                        , family = binomial(link = "logit")
                        , maxit = 10000
                        ,data = SectorsTable
                        ,offset =  log(Area)
                        ,na.action = "na.fail"
                        
)
summary.glm(modelGMLSWAnyCOunt)

#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set<-dredge(modelGMLSWAnyCOunt, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")


topModelSWAnyCountSimplest<-get.models(model.set, subset = 3)[[1]]

summary(topModelSWAnyCountSimplest)

PseudoR2(topModelSWAnyCountSimplest)

#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelSWAnyCountSimplest, level=0.95)

formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)



#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelSWAnyCountSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTable$Sector<-as.factor(SectorsTable$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTable$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTable$X_Centre, list(SectorsTable$Sector), mean)$x
                           ,y =  aggregate(SectorsTable$Y_Centre, list(SectorsTable$Sector), mean)$x)






#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>LARGEST COUNT HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>




SectorsTableForAlrgestColonies<-subset(SectorsTable, (SectorsTable$Count==0 | SectorsTable$Count>=592))
SectorsTableForAlrgestColonies$ColPresence[SectorsTableForAlrgestColonies$Count<592]<-0
SectorsTableForAlrgestColonies$ColPresence[SectorsTableForAlrgestColonies$Count>=592]<-1

SectorsTableForAlrgestColonies$ColPresence<-as.numeric(SectorsTableForAlrgestColonies$ColPresence)



#Global model
modelGLMSWLargestCounts<-glm(ColPresence ~
                               
                              
                               MeanSectorSlope+TKEIQR+PMedian
                             +TKESkewness+U_2Skewness+PIQR
                             +HorizontalIQR+PSkewness+HorizontalSkewness
                             +U_2IQR
                             
                            
                             
                             , family = binomial(link = "logit")
                             , maxit = 10000
                             ,data = SectorsTableForAlrgestColonies
                             ,offset =  log(Area)
                             ,na.action = "na.fail"
                             
)
summary.glm(modelGLMSWLargestCounts)

#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set2<-dredge(modelGLMSWLargestCounts, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")



topModelSWLargestSimplest<-get.models(model.set2, subset = 4)[[1]]

summary(topModelSWLargestSimplest)



PseudoR2(topModelSWLargestSimplest)



#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelSWLargestSimplest, level=0.95)


formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)


#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelSWLargestSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTableForAlrgestColonies$Sector<-as.factor(SectorsTableForAlrgestColonies$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTableForAlrgestColonies$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTableForAlrgestColonies$X_Centre, list(SectorsTableForAlrgestColonies$Sector), mean)$x
                           ,y =  aggregate(SectorsTableForAlrgestColonies$Y_Centre, list(SectorsTableForAlrgestColonies$Sector), mean)$x)



#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>11 Densest HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>




SectorsTableForDensestColonies<-subset(SectorsTable, (SectorsTable$Density==0 | SectorsTable$Density>=0.835))
SectorsTableForDensestColonies$ColPresence[SectorsTableForDensestColonies$Density<0.835]<-0
SectorsTableForDensestColonies$ColPresence[SectorsTableForDensestColonies$Density >=0.835]<-1

SectorsTableForDensestColonies$ColPresence<-as.numeric(SectorsTableForDensestColonies$ColPresence)



#Global model
modelGLMBinaryDensestSW<-glm(ColPresence ~
                               
                               
                               MeanSectorSlope+PMedian+TKESkewness
                             +TKEIQR+PIQR+HorizontalMedian
                             +PSkewness+U_2Skewness+TISkewness
                             +U_2IQR
                             
                          
                             
                             , family = binomial(link = "logit")
                             , maxit = 10000
                             ,data = SectorsTableForDensestColonies
                             #,offset =  log(Area)  #Don't use offset for the 11 densest as it is incorporated in the response classified by density
                             ,na.action = "na.fail"
                             
)
summary.glm(modelGLMBinaryDensestSW)

#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set3<-dredge(modelGLMBinaryDensestSW, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")





topModelSWDensestSimplest<-get.models(model.set3, subset = 7)[[1]]
summary(topModelSWDensestSimplest)




PseudoR2(topModelSWDensestSimplest)



#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelSWDensestSimplest, level=0.95)



formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)


#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelSWDensestSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTableForDensestColonies$Sector<-as.factor(SectorsTableForDensestColonies$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTableForDensestColonies$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTableForDensestColonies$X_Centre, list(SectorsTableForDensestColonies$Sector), mean)$x
                           ,y =  aggregate(SectorsTableForDensestColonies$Y_Centre, list(SectorsTableForDensestColonies$Sector), mean)$x)



#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF SW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF SW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF SW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>




#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR NW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR NW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR NW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR NW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>Any COUNT HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>


SectorsTable$ColPresence[SectorsTable$Count==0]<-0
SectorsTable$ColPresence[SectorsTable$Count>0]<-1

SectorsTable$ColPresence<-as.numeric(SectorsTable$ColPresence)


#Global model
modelGMLNWAnyCOunt<-glm(ColPresence ~
                          
                          TKESkewness+TKEMedian+HorizontalMedian
                        +MeanSectorSlope+HorizontalSkewness
                        
                        +TISkewness+TIIQR+TIMedian
                        +U_2Median+TKEIQR
                       
                        , family = binomial(link = "logit")
                        , maxit = 10000
                        ,data = SectorsTable
                        ,offset =  log(Area)
                        ,na.action = "na.fail"
                        
)
summary.glm(modelGMLNWAnyCOunt)



#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set<-dredge(modelGMLNWAnyCOunt, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")



topModelNWAnyCountSimplest<-get.models(model.set, subset = 3)[[1]]
summary(topModelNWAnyCountSimplest)


PseudoR2(topModelNWAnyCountSimplest)

#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelNWAnyCountSimplest, level=0.95)


formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)

#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelNWAnyCountSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTable$Sector<-as.factor(SectorsTable$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTable$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTable$X_Centre, list(SectorsTable$Sector), mean)$x
                           ,y =  aggregate(SectorsTable$Y_Centre, list(SectorsTable$Sector), mean)$x)


#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>LARGEST COUNT HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

SectorsTableForAlrgestColonies<-subset(SectorsTable, (SectorsTable$Count==0 | SectorsTable$Count>=592))
SectorsTableForAlrgestColonies$ColPresence[SectorsTableForAlrgestColonies$Count<592]<-0
SectorsTableForAlrgestColonies$ColPresence[SectorsTableForAlrgestColonies$Count>=592]<-1

SectorsTableForAlrgestColonies$ColPresence<-as.numeric(SectorsTableForAlrgestColonies$ColPresence)


#Global model
modelGLMNWLargestCounts<-glm(ColPresence ~
                               
                               
                               +TKESkewness+TKEMedian+PMedian
                             +MeanSectorSlope+TKEIQR+U_2Median
                             +U_2IQR+HorizontalMedian
                          
                             , family = binomial(link = "logit")
                             , maxit = 10000
                             ,data = SectorsTableForAlrgestColonies
                             ,offset =  log(Area)
                             ,na.action = "na.fail"
                             
)
summary.glm(modelGLMNWLargestCounts)



#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set2<-dredge(modelGLMNWLargestCounts, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")




topModelNWLargestSimplest<-get.models(model.set2, subset = 2)[[1]]
summary(topModelNWLargestSimplest)

PseudoR2(topModelNWLargestSimplest)


#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelNWLargestSimplest, level=0.95)


formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)


#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelNWLargestSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTableForAlrgestColonies$Sector<-as.factor(SectorsTableForAlrgestColonies$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTableForAlrgestColonies$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTableForAlrgestColonies$X_Centre, list(SectorsTableForAlrgestColonies$Sector), mean)$x
                           ,y =  aggregate(SectorsTableForAlrgestColonies$Y_Centre, list(SectorsTableForAlrgestColonies$Sector), mean)$x)


#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>11 Densest HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

SectorsTableForDensestColonies<-subset(SectorsTable, (SectorsTable$Density==0 | SectorsTable$Density>=0.835))
SectorsTableForDensestColonies$ColPresence[SectorsTableForDensestColonies$Density<0.835]<-0
SectorsTableForDensestColonies$ColPresence[SectorsTableForDensestColonies$Density >=0.835]<-1

SectorsTableForDensestColonies$ColPresence<-as.numeric(SectorsTableForDensestColonies$ColPresence)


#Global model
modelGLMBinaryDensestNW<-glm(ColPresence ~
                               
                               
                               TKESkewness+MeanSectorSlope+TKEMedian
                             +HorizontalMedian+PMedian+TKEIQR
                             +U_2Median
                         
                             
                             , family = binomial(link = "logit")
                             , maxit = 10000
                             ,data = SectorsTableForDensestColonies
                             #,offset =  log(Area)  #Don't use offset for the 11 densest as it is incorporated in the response classified by density
                             ,na.action = "na.fail"
                             
)
summary.glm(modelGLMBinaryDensestNW)



#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set3<-dredge(modelGLMBinaryDensestNW, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")




topModelNWDensestSimplest<-get.models(model.set3, subset = 2)[[1]]
summary(topModelNWDensestSimplest)


PseudoR2(topModelNWDensestSimplest)



#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelNWDensestSimplest, level=0.95)



formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)


#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelNWDensestSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTableForDensestColonies$Sector<-as.factor(SectorsTableForDensestColonies$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTableForDensestColonies$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTableForDensestColonies$X_Centre, list(SectorsTableForDensestColonies$Sector), mean)$x
                           ,y =  aggregate(SectorsTableForDensestColonies$Y_Centre, list(SectorsTableForDensestColonies$Sector), mean)$x)



#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF NW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF NW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF NW MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>




#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR SE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR SE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR SE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR SE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>Any COUNT HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

SectorsTable$ColPresence[SectorsTable$Count==0]<-0
SectorsTable$ColPresence[SectorsTable$Count>0]<-1

SectorsTable$ColPresence<-as.numeric(SectorsTable$ColPresence)


#Global model
modelGMLSEAnyCOunt<-glm(ColPresence ~
                          
                          MeanSectorSlope+HorizontalSkewness+PMedian
                        +PSkewness+U_2IQR+TKEIQR
                        +TKESkewness+U_2Skewness+TISkewness
                        +HorizontalIQR

                        , family = binomial(link = "logit")
                        , maxit = 10000
                        ,data = SectorsTable
                        ,offset =  log(Area)
                        ,na.action = "na.fail"
                        
)
summary.glm(modelGMLSEAnyCOunt)


#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set<-dredge(modelGMLSEAnyCOunt, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")



topModelSEAnyCountSimplest<-get.models(model.set, subset = 2)[[1]]
summary(topModelSEAnyCountSimplest)

PseudoR2(topModelSEAnyCountSimplest)


#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelSEAnyCountSimplest, level=0.95)



formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)

#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelSEAnyCountSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTable$Sector<-as.factor(SectorsTable$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTable$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTable$X_Centre, list(SectorsTable$Sector), mean)$x
                           ,y =  aggregate(SectorsTable$Y_Centre, list(SectorsTable$Sector), mean)$x)


#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>LARGEST COUNT HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

SectorsTableForAlrgestColonies<-subset(SectorsTable, (SectorsTable$Count==0 | SectorsTable$Count>=592))
SectorsTableForAlrgestColonies$ColPresence[SectorsTableForAlrgestColonies$Count<592]<-0
SectorsTableForAlrgestColonies$ColPresence[SectorsTableForAlrgestColonies$Count>=592]<-1

SectorsTableForAlrgestColonies$ColPresence<-as.numeric(SectorsTableForAlrgestColonies$ColPresence)




#Global model
modelGLMSELargestCounts<-glm(ColPresence ~
                               
                               
                               U_2Skewness+MeanSectorSlope+U_2IQR
                             +TKEMedian+PSkewness+TISkewness
                             +TKESkewness+HorizontalMedian+TKEIQR
                             +HorizontalIQR

                             , family = binomial(link = "logit")
                             , maxit = 10000
                             ,data = SectorsTableForAlrgestColonies
                             ,offset =  log(Area)
                             ,na.action = "na.fail"
                             
)
summary.glm(modelGLMSELargestCounts)


#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set2<-dredge(modelGLMSELargestCounts, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")




topModelSELargestSimplest<-get.models(model.set2, subset = 4)[[1]]
summary(topModelSELargestSimplest)


PseudoR2(topModelSELargestSimplest)



#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelSELargestSimplest, level=0.95)



formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)


#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelSELargestSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTableForAlrgestColonies$Sector<-as.factor(SectorsTableForAlrgestColonies$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTableForAlrgestColonies$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTableForAlrgestColonies$X_Centre, list(SectorsTableForAlrgestColonies$Sector), mean)$x
                           ,y =  aggregate(SectorsTableForAlrgestColonies$Y_Centre, list(SectorsTableForAlrgestColonies$Sector), mean)$x)



#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>11 Densest HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>


SectorsTableForDensestColonies<-subset(SectorsTable, (SectorsTable$Density==0 | SectorsTable$Density>=0.835))
SectorsTableForDensestColonies$ColPresence[SectorsTableForDensestColonies$Density<0.835]<-0
SectorsTableForDensestColonies$ColPresence[SectorsTableForDensestColonies$Density >=0.835]<-1

SectorsTableForDensestColonies$ColPresence<-as.numeric(SectorsTableForDensestColonies$ColPresence)



#Global model
modelGLMBinaryDensestSE<-glm(ColPresence ~
                               
                               
                               MeanSectorSlope+U_2Skewness+TKEIQR
                             +U_2IQR+PSkewness+TKESkewness
                             +TISkewness+HorizontalMedian+HorizontalIQR
                             +U_2Median
                             

                             , family = binomial(link = "logit")
                             , maxit = 10000
                             ,data = SectorsTableForDensestColonies
                             #,offset =  log(Area)  #Don't use offset for the 11 densest as it is incorporated in the response classified by density
                             ,na.action = "na.fail"
                             
)
summary.glm(modelGLMBinaryDensestSE)


#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set3<-dredge(modelGLMBinaryDensestSE, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")


topModelSEDensestSimplest<-get.models(model.set3, subset = 1)[[1]]
summary(topModelSEDensestSimplest)

PseudoR2(topModelSEDensestSimplest)


#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelSEDensestSimplest, level=0.95)



formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)


#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelSEDensestSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTableForDensestColonies$Sector<-as.factor(SectorsTableForDensestColonies$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTableForDensestColonies$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTableForDensestColonies$X_Centre, list(SectorsTableForDensestColonies$Sector), mean)$x
                           ,y =  aggregate(SectorsTableForDensestColonies$Y_Centre, list(SectorsTableForDensestColonies$Sector), mean)$x)



#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF SE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF SE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF SE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>



#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR NE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR NE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR NE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>FOR NE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>Any COUNT HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>


SectorsTable$ColPresence[SectorsTable$Count==0]<-0
SectorsTable$ColPresence[SectorsTable$Count>0]<-1

SectorsTable$ColPresence<-as.numeric(SectorsTable$ColPresence)



#Global model
modelGMLNEAnyCOunt<-glm(ColPresence ~
                          TKEMedian+TKESkewness+U_2Skewness
                        +U_2IQR+HorizontalMedian+MeanSectorSlope
                        +TKEIQR+HorizontalSkewness+TISkewness
                        +PIQR
                        
                        
                        , family = binomial(link = "logit")
                        , maxit = 10000
                        ,data = SectorsTable
                        ,offset =  log(Area)
                        ,na.action = "na.fail"
                        
)
summary.glm(modelGMLNEAnyCOunt)

#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set<-dredge(modelGMLNEAnyCOunt, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")




topModelNEAnyCountSimplest<-get.models(model.set, subset = 3)[[1]]
summary(topModelNEAnyCountSimplest)


PseudoR2(topModelNEAnyCountSimplest)



#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelNEAnyCountSimplest, level=0.95)



formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)


#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelNEAnyCountSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTable$Sector<-as.factor(SectorsTable$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTable$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTable$X_Centre, list(SectorsTable$Sector), mean)$x
                           ,y =  aggregate(SectorsTable$Y_Centre, list(SectorsTable$Sector), mean)$x)



#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>LARGEST COUNT HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

SectorsTableForAlrgestColonies<-subset(SectorsTable, (SectorsTable$Count==0 | SectorsTable$Count>=592))
SectorsTableForAlrgestColonies$ColPresence[SectorsTableForAlrgestColonies$Count<592]<-0
SectorsTableForAlrgestColonies$ColPresence[SectorsTableForAlrgestColonies$Count>=592]<-1

SectorsTableForAlrgestColonies$ColPresence<-as.numeric(SectorsTableForAlrgestColonies$ColPresence)



#Global model
modelGLMNELargestCounts<-glm(ColPresence ~
                               
                               
                               PIQR+TKEMedian+TKEIQR
                             +MeanSectorSlope+HorizontalSkewness+U_2Skewness
                             +U_2Median+HorizontalMedian+TIMedian
                             +TKESkewness
                            
                                
                             , family = binomial(link = "logit")
                             , maxit = 10000
                             ,data = SectorsTableForAlrgestColonies
                             ,offset =  log(Area)
                             ,na.action = "na.fail"
                             
)
summary.glm(modelGLMNELargestCounts)



#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set2<-dredge(modelGLMNELargestCounts, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")




topModelNELargestSimplest<-get.models(model.set2, subset = 2)[[1]]
summary(topModelNELargestSimplest)

PseudoR2(topModelNELargestSimplest)



#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelNELargestSimplest, level=0.95)


formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)

#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelNELargestSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTableForAlrgestColonies$Sector<-as.factor(SectorsTableForAlrgestColonies$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTableForAlrgestColonies$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTableForAlrgestColonies$X_Centre, list(SectorsTableForAlrgestColonies$Sector), mean)$x
                           ,y =  aggregate(SectorsTableForAlrgestColonies$Y_Centre, list(SectorsTableForAlrgestColonies$Sector), mean)$x)

#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>11 Densest HYPOTHESIS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>


SectorsTableForDensestColonies<-subset(SectorsTable, (SectorsTable$Density==0 | SectorsTable$Density>=0.835))
SectorsTableForDensestColonies$ColPresence[SectorsTableForDensestColonies$Density<0.835]<-0
SectorsTableForDensestColonies$ColPresence[SectorsTableForDensestColonies$Density >=0.835]<-1

SectorsTableForDensestColonies$ColPresence<-as.numeric(SectorsTableForDensestColonies$ColPresence)


#Global model
modelGLMBinaryDensestNE<-glm(ColPresence ~
                               
                               
                               TKEMedian+TKESkewness+MeanSectorSlope
                             +HorizontalSkewness+U_2Median+TKEIQR
                             +TISkewness+U_2Skewness+TIIQR
                             +HorizontalMedian
                             
                             
                             , family = binomial(link = "logit")
                             , maxit = 10000
                             ,data = SectorsTableForDensestColonies
                             #,offset =  log(Area)  #Don't use offset for the 11 densest as it is incorporated in the response classified by density
                             ,na.action = "na.fail"
                             
)
summary.glm(modelGLMBinaryDensestNE)


#Use dredge  to get the model set from the standardized global model
options(na.action = "na.fail")
model.set3<-dredge(modelGLMBinaryDensestNE, rank = "BIC",extra = "R^2")
options(na.action = "na.omit")



topModelNEDensestSimplest<-get.models(model.set3, subset = 1)[[1]]
summary(topModelNEDensestSimplest)


PseudoR2(topModelNEDensestSimplest)



#To estimate odds ratio with 95% CI
OR<-odds.ratio(topModelNEDensestSimplest, level=0.95)



formatC(OR$OR, format = "e", digits = 1)
formatC(OR$`2.5 %`, format = "e", digits = 1)
formatC(OR$`97.5 %`, format = "e", digits = 1)


#Assess model residuals.

simulationOutput <-simulateResiduals(fittedModel = topModelNEDensestSimplest, n =2000) #or 250
plot(simulationOutput)


SectorsTableForDensestColonies$Sector<-as.factor(SectorsTableForDensestColonies$Sector)

#Assess spatial autocorrelation
simulationOutputSpatial = recalculateResiduals(simulationOutput, group = SectorsTableForDensestColonies$Sector)
testSpatialAutocorrelation(simulationOutputSpatial 
                           ,x =  aggregate(SectorsTableForDensestColonies$X_Centre, list(SectorsTableForDensestColonies$Sector), mean)$x
                           ,y =  aggregate(SectorsTableForDensestColonies$Y_Centre, list(SectorsTableForDensestColonies$Sector), mean)$x)


#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF NE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF NE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>END OF NE MODELS>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>




